#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Apr 28 22:37:23 2020

@author: Sara Ben Shabbat
"""

__version__ = "1.1.5"
import os, sys; sys.path.append(os.path.dirname(os.path.realpath(__file__)))



